@@ -145,6 +145,7 @@ func (f *Fs) newUpstream(ctx context.Context, dir, remote string) (*upstream, er
 		dir:            dir,
 		pathAdjustment: newAdjustment(f.root, dir),
 	}
+	cache.PinUntilFinalized(u.f, u)
 	return u, nil
 }
 
@@ -206,9 +207,13 @@ func NewFs(ctx context.Context, name, root string, m configmap.Mapper) (outFs fs
 				return err
 			}
 			mu.Lock()
-			f.upstreams[dir] = u
+			if _, found := f.upstreams[dir]; found {
+				err = fmt.Errorf("duplicate directory name %q", dir)
+			} else {
+				f.upstreams[dir] = u
+			}
 			mu.Unlock()
-			return nil
+			return err
 		})
 	}
 	err = g.Wait()
