@@ -29,7 +29,7 @@ var commandDefinition = &cobra.Command{
 rclone cryptdecode returns unencrypted file names when provided with
 a list of encrypted file names. List limit is 10 items.
 
-If you supply the --reverse flag, it will return encrypted file names.
+If you supply the ` + "`--reverse`" + ` flag, it will return encrypted file names.
 
 use it like this
 
@@ -37,8 +37,8 @@ use it like this
 
 	rclone cryptdecode --reverse encryptedremote: filename1 filename2
 
-Another way to accomplish this is by using the ` + "`rclone backend encode` (or `decode`)" + `command.
-See the documentation on the ` + "`crypt`" + ` overlay for more info.
+Another way to accomplish this is by using the ` + "`rclone backend encode` (or `decode`)" + ` command.
+See the documentation on the [crypt](/crypt/) overlay for more info.
 `,
 	Run: func(command *cobra.Command, args []string) {
 		cmd.CheckArgs(2, 11, command, args)
@@ -48,7 +48,7 @@ See the documentation on the ` + "`crypt`" + ` overlay for more info.
 				return err
 			}
 			if fsInfo.Name != "crypt" {
-				return errors.New("The remote needs to be of type \"crypt\"")
+				return errors.New("the remote needs to be of type \"crypt\"")
 			}
 			cipher, err := crypt.NewCipher(config)
 			if err != nil {
@@ -75,7 +75,7 @@ func cryptDecode(cipher *crypt.Cipher, args []string) error {
 		}
 	}
 
-	fmt.Printf(output)
+	fmt.Print(output)
 
 	return nil
 }
@@ -89,7 +89,7 @@ func cryptEncode(cipher *crypt.Cipher, args []string) error {
 		output += fmt.Sprintln(fileName, "\t", encryptedFileName)
 	}
 
-	fmt.Printf(output)
+	fmt.Print(output)
 
 	return nil
 }
