@@ -26,15 +26,16 @@ that only contain empty directories), that it finds under the path.
 The root path itself will also be removed if it is empty, unless
 you supply the ` + "`--leave-root`" + ` flag.
 
-Use command ` + "`rmdir`" + ` to delete just the empty directory
-given by path, not recurse.
+Use command [rmdir](/commands/rclone_rmdir/) to delete just the empty
+directory given by path, not recurse.
 
 This is useful for tidying up remotes that rclone has left a lot of
-empty directories in. For example the ` + "`delete`" + ` command will
-delete files but leave the directory structure (unless used with
-option ` + "`--rmdirs`" + `).
+empty directories in. For example the [delete](/commands/rclone_delete/)
+command will delete files but leave the directory structure (unless
+used with option ` + "`--rmdirs`" + `).
 
-To delete a path and any objects in it, use ` + "`purge`" + ` command.
+To delete a path and any objects in it, use [purge](/commands/rclone_purge/)
+command.
 `,
 	Run: func(command *cobra.Command, args []string) {
 		cmd.CheckArgs(1, 1, command, args)
