@@ -200,9 +200,7 @@ func InstallUpdate(ctx context.Context, opt *Options) error {
 	savedFile := ""
 	if runtime.GOOS == "windows" {
 		savedFile = targetFile
-		if strings.HasSuffix(savedFile, ".exe") {
-			savedFile = savedFile[:len(savedFile)-4]
-		}
+		savedFile = strings.TrimSuffix(savedFile, ".exe")
 		savedFile += ".old.exe"
 	}
 
@@ -319,9 +317,7 @@ func makeRandomExeName(baseName, extension string) (string, error) {
 	const maxAttempts = 5
 
 	if runtime.GOOS == "windows" {
-		if strings.HasSuffix(baseName, ".exe") {
-			baseName = baseName[:len(baseName)-4]
-		}
+		baseName = strings.TrimSuffix(baseName, ".exe")
 		extension += ".exe"
 	}
 
