@@ -41,8 +41,8 @@ func init() {
 var Command = &cobra.Command{
 	Use:   "serve <protocol> [opts] <remote>",
 	Short: `Serve a remote over a protocol.`,
-	Long: `rclone serve is used to serve a remote over a given protocol. This
-command requires the use of a subcommand to specify the protocol, e.g.
+	Long: `Serve a remote over a given protocol. Requires the use of a
+subcommand to specify the protocol, e.g.
 
     rclone serve http remote:
 
