@@ -47,7 +47,7 @@ Or just provide remote directory and all files in directory will be tiered
 		cmd.Run(false, false, command, func() error {
 			isSupported := fsrc.Features().SetTier
 			if !isSupported {
-				return fmt.Errorf("Remote %s does not support settier", fsrc.Name())
+				return fmt.Errorf("remote %s does not support settier", fsrc.Name())
 			}
 
 			return operations.SetTier(context.Background(), fsrc, tier)
