@@ -28,6 +28,10 @@ not supported by the remote, no hash will be returned.  With the
 download flag, the file will be downloaded from the remote and
 hashed locally enabling SHA-1 for any remote.
 
+For other algorithms, see the [hashsum](/commands/rclone_hashsum/)
+command. Running ` + "`rclone sha1sum remote:path`" + ` is equivalent
+to running ` + "`rclone hashsum SHA1 remote:path`" + `.
+
 This command can also hash data received on standard input (stdin),
 by not passing a remote:path, or by passing a hyphen as remote:path
 when there is data to read (if not, the hypen will be treated literaly,
