@@ -10,6 +10,7 @@ import (
 	"reflect"
 	"sort"
 	"strings"
+	"sync"
 
 	"github.com/rclone/rclone/fs/config/configmap"
 	"github.com/rclone/rclone/fs/config/configstruct"
@@ -40,11 +41,13 @@ type RegInfo struct {
 	Aliases []string
 	// Hide - if set don't show in the configurator
 	Hide bool
+	// MetadataInfo help about the metadata in use in this backend
+	MetadataInfo *MetadataInfo
 }
 
 // FileName returns the on disk file name for this backend
 func (ri *RegInfo) FileName() string {
-	return strings.Replace(ri.Name, " ", "", -1)
+	return strings.ReplaceAll(ri.Name, " ", "")
 }
 
 // Options is a slice of configuration Option for a backend
@@ -210,7 +213,7 @@ func (o *Option) Type() string {
 
 // FlagName for the option
 func (o *Option) FlagName(prefix string) string {
-	name := strings.Replace(o.Name, "_", "-", -1) // convert snake_case to kebab-case
+	name := strings.ReplaceAll(o.Name, "_", "-") // convert snake_case to kebab-case
 	if !o.NoPrefix {
 		name = prefix + "-" + name
 	}
@@ -299,3 +302,33 @@ func MustFind(name string) *RegInfo {
 	}
 	return fs
 }
+
+// Type returns a textual string to identify the type of the remote
+func Type(f Fs) string {
+	typeName := fmt.Sprintf("%T", f)
+	typeName = strings.TrimPrefix(typeName, "*")
+	typeName = strings.TrimSuffix(typeName, ".Fs")
+	return typeName
+}
+
+var (
+	typeToRegInfoMu sync.Mutex
+	typeToRegInfo   = map[string]*RegInfo{}
+)
+
+// Add the RegInfo to the reverse map
+func addReverse(f Fs, fsInfo *RegInfo) {
+	typeToRegInfoMu.Lock()
+	defer typeToRegInfoMu.Unlock()
+	typeToRegInfo[Type(f)] = fsInfo
+}
+
+// FindFromFs finds the *RegInfo used to create this Fs, provided
+// it was created by fs.NewFs or cache.Get
+//
+// It returns nil if not found
+func FindFromFs(f Fs) *RegInfo {
+	typeToRegInfoMu.Lock()
+	defer typeToRegInfoMu.Unlock()
+	return typeToRegInfo[Type(f)]
+}
