@@ -17,10 +17,7 @@ func TestWriteFileDoubleClose(t *testing.T) {
 
 // writeTestDup performs the platform-specific implementation of the dup() syscall
 func writeTestDup(oldfd uintptr) (uintptr, error) {
-	p, err := windows.GetCurrentProcess()
-	if err != nil {
-		return 0, err
-	}
+	p := windows.CurrentProcess()
 	var h windows.Handle
 	return uintptr(h), windows.DuplicateHandle(p, windows.Handle(oldfd), p, &h, 0, true, windows.DUPLICATE_SAME_ACCESS)
 }
